@@ -1,12 +1,13 @@
-from pokeman.pokeman import Pokeman
+from pokeman.pokeman_o import Pokeman
 from pokeman.amqp_resources.globals import Exchange, RoutingKey, Queue
 from pokeman.amqp_resources import heapq
+from pokeman import amqp_resources
 from pokeman.composite import ConnectionParameters, Connection, BasicConfig
 from pokeman.coatings import BasicMessage, BasicMessageConsumer, PollingConsumer, SelectiveConsumer, Ptypes
 
 
 
-__version__ = '0.1.8'
+__version__ = '0.1.11'
 
 
 __all__ = [
